==> jboss-osgi-jta-1.0.0-sources.jar: org/jboss/osgi/jta/TransactionCapability.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.jta;

//$Id: TransactionCapability.java 95892 2009-11-01 12:22:13Z thomas.diesler@jboss.com $

import java.io.File;

import javax.transaction.TransactionManager;

import org.jboss.osgi.spi.capability.Capability;

import com.arjuna.ats.arjuna.common.Environment;

/**
 * Adds the Transaction capability to the {@link OSGiRuntime}
 * under test. 
 * 
 * It is ignored if the {@link TransactionManager} service is already registered.
 * 
 * Installed bundles: jboss-osgi-jta.jar
 * 
 * @author thomas.diesler@jboss.com
 * @since 27-Oct-2009
 */
public class TransactionCapability extends Capability
{
   public TransactionCapability()
   {
      super(TransactionCapabilityMarker.class.getName());
      
      if (new File("target").exists())
         addSystemProperty(Environment.OBJECTSTORE_DIR, "target/ObjectStore");
      
      addBundle("bundles/jboss-osgi-jta.jar");
   }
}

==> jboss-osgi-jta-4.6.1-sources.jar: org/jboss/osgi/jta/TransactionCapability.java <==
/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.jta;

//$Id$

import java.io.File;

import javax.transaction.TransactionManager;

import org.jboss.osgi.spi.capability.Capability;
import org.jboss.osgi.testing.OSGiRuntime;
import org.jboss.osgi.xml.XMLParserCapability;

import com.arjuna.ats.arjuna.common.Environment;


/**
 * Adds the Transaction capability to the {@link OSGiRuntime}
 * under test. 
 * 
 * It is ignored if the {@link TransactionManager} service is already registered.
 * 
 * Installed bundles: jboss-osgi-jta.jar
 * 
 * @author thomas.diesler@jboss.com
 * @since 27-Oct-2009
 */
public class TransactionCapability extends Capability
{
   public TransactionCapability()
   {
      super(TransactionCapabilityMarker.class.getName());
      
      if (new File("target").exists())
         addSystemProperty(Environment.OBJECTSTORE_DIR, "target/ObjectStore");
      
      addDependency(new XMLParserCapability());
      
      addBundle("bundles/jboss-osgi-jta.jar");
   }
}
